@@ -144,11 +144,19 @@ void Session::processResponse(const KManageSieve::Response &response, const QByt
             m_implementation = QString::fromLatin1(response.value());
             qCDebug(KMANAGERSIEVE_LOG) << objectName() << "Connected to Sieve server: " << response.value();
         } else if (response.key() == "SASL") {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             m_saslMethods = QString::fromLatin1(response.value()).split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+            m_saslMethods = QString::fromLatin1(response.value()).split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
             qCDebug(KMANAGERSIEVE_LOG) << objectName() << "Server SASL authentication methods: " << m_saslMethods;
         } else if (response.key() == "SIEVE") {
             // Save script capabilities
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             m_sieveExtensions = QString::fromLatin1(response.value()).split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+            m_sieveExtensions = QString::fromLatin1(response.value()).split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
             qCDebug(KMANAGERSIEVE_LOG) << objectName() << "Server script capabilities: " << m_sieveExtensions;
         } else if (response.key() == "STARTTLS") {
             qCDebug(KMANAGERSIEVE_LOG) << objectName() << "Server supports TLS";
@@ -196,7 +204,7 @@ void Session::scheduleJob(SieveJob *job)
 
 void Session::killJob(SieveJob *job, KJob::KillVerbosity verbosity)
 {
-    qCDebug(KMANAGERSIEVE_LOG) << objectName() << Q_FUNC_INFO << job;
+    qCDebug(KMANAGERSIEVE_LOG) << objectName() << Q_FUNC_INFO << "job " << job << " m_currentJob " << m_currentJob << " verbosity " << verbosity;
     if (m_currentJob == job) {
         if (verbosity == KJob::EmitResult) {
             m_currentJob->d->killed();
@@ -206,6 +214,8 @@ void Session::killJob(SieveJob *job, KJob::KillVerbosity verbosity)
         m_jobs.removeAll(job);
         if (verbosity == KJob::EmitResult) {
             job->d->killed();
+        } else {
+            job->deleteLater();
         }
     }
 }
@@ -333,10 +343,10 @@ void Session::setErrorMessage(int error, const QString &msg)
         m_currentJob->setErrorMessage(msg);
     } else {
         // Don't bother the user about idle timeout
-        if (error != QAbstractSocket::RemoteHostClosedError &&
-            error != QAbstractSocket::SocketTimeoutError) {
+        if (error != QAbstractSocket::RemoteHostClosedError
+            && error != QAbstractSocket::SocketTimeoutError) {
             qCWarning(KMANAGERSIEVE_LOG) << objectName() << "No job for reporting this error message!" << msg << "host" << m_url.host() << "error" << error;
-            KMessageBox::error(nullptr, i18n("The Sieve server on %1 has reported an error:\n%2", m_url.host(),msg), i18n("Sieve Manager"));
+            KMessageBox::error(nullptr, i18n("The Sieve server on %1 has reported an error:\n%2", m_url.host(), msg), i18n("Sieve Manager"));
         }
     }
 }
