@@ -84,7 +84,11 @@ void SessionThread::doInit()
     Q_ASSERT(QThread::currentThread() == thread());
     m_socket = std::make_unique<QSslSocket>();
     connect(m_socket.get(), &QSslSocket::readyRead, this, &SessionThread::slotDataReceived);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_socket.get(), QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::error), this, &SessionThread::slotSocketError);
+#else
+    connect(m_socket.get(), QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::errorOccurred), this, &SessionThread::slotSocketError);
+#endif
     connect(m_socket.get(), &QSslSocket::disconnected, this, &SessionThread::socketDisconnected);
     connect(m_socket.get(), &QSslSocket::connected, this, &SessionThread::socketConnected);
 }
@@ -210,9 +214,13 @@ void SessionThread::slotSocketError()
 {
     Q_ASSERT(QThread::currentThread() == thread());
 
-    qCWarning(KMANAGERSIEVE_LOG) << Q_FUNC_INFO << m_socket->error() << m_socket->errorString();
+    qCWarning(KMANAGERSIEVE_LOG) << Q_FUNC_INFO
+                                 <<m_socket->error()
+                                 << m_socket->errorString();
 
-    Q_EMIT error(m_socket->error(), m_socket->errorString());
+    Q_EMIT error(
+        m_socket->error(),
+        m_socket->errorString());
     doDisconnectFromHost(false);
 }
 
@@ -302,7 +310,7 @@ void SessionThread::doContinueAuthentication(const Response &response, const QBy
             Q_EMIT authenticationDone();
         } else {
             Q_EMIT error(QAbstractSocket::UnknownSocketError, KIO::buildErrorString(KIO::ERR_CANNOT_AUTHENTICATE,
-                                               i18n("Authentication failed.\nMost likely the password is wrong.\nThe server responded:\n%1", QString::fromLatin1(response.action()))));
+                                                                                    i18n("Authentication failed.\nMost likely the password is wrong.\nThe server responded:\n%1", QString::fromLatin1(response.action()))));
             doDisconnectFromHost(true);
         }
     }
@@ -453,7 +461,11 @@ void SessionThread::sslResult(bool encrypted)
     Q_ASSERT(QThread::currentThread() == thread());
 
     const QSslCipher cipher = m_socket->sessionCipher();
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     const int numberOfSslError = m_socket->sslErrors().count();
+#else
+    const int numberOfSslError = m_socket->sslHandshakeErrors().count();
+#endif
     if (!encrypted || numberOfSslError > 0 || !m_socket->isEncrypted()
         || cipher.isNull() || cipher.usedBits() == 0) {
         qCDebug(KMANAGERSIEVE_LOG) << "Initial SSL handshake failed. cipher.isNull() is" << cipher.isNull()
