@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,7 +28,7 @@ public:
     explicit SieveActionAddHeader(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
     Q_REQUIRED_RESULT QString code(QWidget *w) const override;
     Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
-    Q_REQUIRED_RESULT bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    void setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
     Q_REQUIRED_RESULT QString help() const override;
     Q_REQUIRED_RESULT QUrl href() const override;
 };
