@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -38,7 +38,7 @@ QWidget *SieveActionBreak::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     w->setLayout(lay);
 
     QLabel *lab = new QLabel(i18n("Name (optional):"));
@@ -51,7 +51,7 @@ QWidget *SieveActionBreak::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionBreak::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionBreak::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
@@ -61,7 +61,7 @@ bool SieveActionBreak::setParamWidgetValue(QXmlStreamReader &element, QWidget *w
                 QLineEdit *name = w->findChild<QLineEdit *>(QStringLiteral("name"));
                 name->setText(AutoCreateScriptUtil::strValue(element));
             } else {
-                unknowTagValue(tagValue, error);
+                unknownTagValue(tagValue, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveActionBreak::setParamWidgetValue unknown tagValue " << tagValue;
             }
         } else if (tagName == QLatin1String("str")) {
@@ -78,8 +78,6 @@ bool SieveActionBreak::setParamWidgetValue(QXmlStreamReader &element, QWidget *w
             qCDebug(LIBKSIEVE_LOG) << "SieveActionBreak::setParamWidgetValue unknown tag " << tagName;
         }
     }
-
-    return true;
 }
 
 QUrl SieveActionBreak::href() const
