@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 #ifndef SELECTIMPORTANCECOMBOBOX_H
 #define SELECTIMPORTANCECOMBOBOX_H
 
-#include <KComboBox>
+#include <QComboBox>
 
 namespace KSieveUi {
-class SelectImportanceCombobox : public KComboBox
+class SelectImportanceCombobox : public QComboBox
 {
     Q_OBJECT
 public:
