@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,6 +19,7 @@
 
 #include "sievecondition.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
+#include "libksieve_debug.h"
 
 #include <KLocalizedString>
 
@@ -27,10 +28,7 @@
 using namespace KSieveUi;
 
 SieveCondition::SieveCondition(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent)
-    : QObject(parent)
-    , mSieveGraphicalModeWidget(sieveGraphicalModeWidget)
-    , mName(name)
-    , mLabel(label)
+    : SieveCommonActionCondition(sieveGraphicalModeWidget, name, label, parent)
 {
 }
 
@@ -38,64 +36,8 @@ SieveCondition::~SieveCondition()
 {
 }
 
-QStringList SieveCondition::sieveCapabilities() const
+void SieveCondition::setParamWidgetValue(QXmlStreamReader & /*element*/, QWidget * /*parent*/, bool /*notCondition*/, QString & /*error*/)
 {
-    if (mSieveGraphicalModeWidget) {
-        return mSieveGraphicalModeWidget->sieveCapabilities();
-    }
-    return {};
-}
-
-QString SieveCondition::name() const
-{
-    return mName;
-}
-
-QString SieveCondition::label() const
-{
-    return mLabel;
-}
-
-SieveCondition *SieveCondition::newAction()
-{
-    return nullptr;
-}
-
-QWidget *SieveCondition::createParamWidget(QWidget *parent) const
-{
-    return new QWidget(parent);
-}
-
-QString SieveCondition::code(QWidget *parent) const
-{
-    Q_UNUSED(parent);
-    return QString();
-}
-
-QStringList SieveCondition::needRequires(QWidget *parent) const
-{
-    Q_UNUSED(parent);
-    return QStringList();
-}
-
-bool SieveCondition::needCheckIfServerHasCapability() const
-{
-    return false;
-}
-
-QString SieveCondition::serverNeedsCapability() const
-{
-    return QString();
-}
-
-QString SieveCondition::help() const
-{
-    return QString();
-}
-
-bool SieveCondition::setParamWidgetValue(QXmlStreamReader & /*element*/, QWidget * /*parent*/, bool /*notCondition*/, QString & /*error*/)
-{
-    return true;
 }
 
 void SieveCondition::unknownTag(const QStringRef &tag, QString &error)
@@ -103,42 +45,22 @@ void SieveCondition::unknownTag(const QStringRef &tag, QString &error)
     error += i18n("Unknown tag \"%1\" during parsing condition \"%2\"", *tag.string(), name()) + QLatin1Char('\n');
 }
 
-void SieveCondition::unknowTagValue(const QString &tagValue, QString &error)
+void SieveCondition::unknownTagValue(const QString &tagValue, QString &error)
 {
     error += i18n("An unknown tag value \"%1\" was found during parsing condition \"%2\".", tagValue, name()) + QLatin1Char('\n');
 }
 
-void SieveCondition::tooManyArgument(const QString &tagName, int index, int maxValue, QString &error)
+void SieveCondition::tooManyArguments(const QString &tagName, int index, int maxValue, QString &error)
 {
     error += i18n("Too many argument found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, (index + 1), tagName) + QLatin1Char('\n');
 }
 
-void SieveCondition::tooManyArgument(const QStringRef &tagName, int index, int maxValue, QString &error)
+void SieveCondition::tooManyArguments(const QStringRef &tagName, int index, int maxValue, QString &error)
 {
-    tooManyArgument(tagName.toString(), index, maxValue, error);
+    tooManyArguments(tagName.toString(), index, maxValue, error);
 }
 
 void SieveCondition::serverDoesNotSupportFeatures(const QString &feature, QString &error)
 {
     error += i18n("A feature \"%1\" in condition \"%2\" is not supported by server", feature, name()) + QLatin1Char('\n');
 }
-
-QUrl SieveCondition::href() const
-{
-    return QUrl();
-}
-
-QString SieveCondition::comment() const
-{
-    return mComment;
-}
-
-void SieveCondition::setComment(const QString &comment)
-{
-    mComment = comment;
-}
-
-QString SieveCondition::generateComment() const
-{
-    return {};
-}
