@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,6 +20,7 @@
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "editor/sieveeditorutil.h"
+#include "util/sieveimapaccountsettings.h"
 #include <KLocalizedString>
 #include <QLineEdit>
 
@@ -56,6 +57,7 @@ QWidget *SieveConditionMetaData::createParamWidget(QWidget *parent) const
     grid->addWidget(lab, 0, 0);
 
     KSieveUi::AbstractMoveImapFolderWidget *mailbox = AutoCreateScriptUtil::createImapFolderWidget();
+    mailbox->setSieveImapAccountSettings(sieveImapAccountSettings());
 
     connect(mailbox, &KSieveUi::AbstractMoveImapFolderWidget::textChanged, this, &SieveConditionMetaData::valueChanged);
     mailbox->setObjectName(QStringLiteral("mailbox"));
@@ -128,7 +130,7 @@ QString SieveConditionMetaData::help() const
         "This test retrieves the value of the mailbox annotation \"annotation-name\" for the mailbox \"mailbox\". The retrieved value is compared to the \"key-list\". The test returns true if the annotation exists and its value matches any of the keys.");
 }
 
-bool SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
+void SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
 {
     int index = 0;
     QString commentStr;
@@ -156,7 +158,7 @@ bool SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWid
                 break;
             }
             default:
-                tooManyArgument(tagName, index, 3, error);
+                tooManyArguments(tagName, index, 3, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionMetaData::setParamWidgetValue too many argument " << index;
                 break;
             }
@@ -177,8 +179,6 @@ bool SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWid
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-
-    return true;
 }
 
 QUrl SieveConditionMetaData::href() const
