@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -38,7 +38,7 @@ QWidget *SieveConditionSize::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     w->setLayout(lay);
 
     QComboBox *combo = new QComboBox;
@@ -69,7 +69,7 @@ QString SieveConditionSize::help() const
     return i18n("The \"size\" test deals with the size of a message.  It takes either a tagged argument of \":over\" or \":under\", followed by a number representing the size of the message.");
 }
 
-bool SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
+void SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
 {
     QString commentStr;
     while (element.readNextStartElement()) {
@@ -83,8 +83,8 @@ bool SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
         } else if (tagName == QLatin1String("num")) {
             QString numIdentifier;
-            if (element.attributes().hasAttribute(QStringLiteral("quantifier"))) {
-                numIdentifier = element.attributes().value(QStringLiteral("quantifier")).toString();
+            if (element.attributes().hasAttribute(QLatin1String("quantifier"))) {
+                numIdentifier = element.attributes().value(QLatin1String("quantifier")).toString();
             }
             const qlonglong tagValue = element.readElementText().toLongLong();
             SelectSizeWidget *sizeWidget = w->findChild<SelectSizeWidget *>(QStringLiteral("sizewidget"));
@@ -102,8 +102,6 @@ bool SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-
-    return true;
 }
 
 QUrl SieveConditionSize::href() const
