@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -122,7 +122,7 @@ QString SieveConditionSpamTest::help() const
     return i18n("Sieve implementations that implement the \"spamtest\" test use an identifier of either \"spamtest\" or \"spamtestplus\" for use with the capability mechanism.");
 }
 
-bool SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
+void SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
 {
     QString commentStr;
     while (element.readNextStartElement()) {
@@ -152,7 +152,7 @@ bool SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWid
                     qCDebug(LIBKSIEVE_LOG) << " SieveConditionSpamTest::setParamWidgetValue server has not percent support";
                 }
             } else {
-                unknowTagValue(tagValue, error);
+                unknownTagValue(tagValue, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionSpamTest::setParamWidgetValue unknown tagvalue " << tagValue;
             }
         } else if (tagName == QLatin1String("str")) {
@@ -171,7 +171,6 @@ bool SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWid
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-    return true;
 }
 
 QUrl SieveConditionSpamTest::href() const
