@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,7 +21,7 @@
 
 #include <QWidget>
 
-class KComboBox;
+class QComboBox;
 class QLineEdit;
 
 namespace KSieveUi {
@@ -40,7 +40,7 @@ Q_SIGNALS:
 private:
     void slotBodyTypeChanged(int);
     void initialize();
-    KComboBox *mBodyCombobox = nullptr;
+    QComboBox *mBodyCombobox = nullptr;
     QLineEdit *mBodyLineEdit = nullptr;
 };
 }
