@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,10 +18,11 @@
 */
 #include "selectheadertypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <KLocalizedString>
-#include <KLineEdit>
 #include <QPushButton>
+#include <QLineEdit>
+#include <QPointer>
 #include <QIcon>
 
 #include <QVBoxLayout>
@@ -30,6 +31,8 @@
 #include <KSharedConfig>
 #include <QDialogButtonBox>
 #include <KConfigGroup>
+#include <QEvent>
+#include <QKeyEvent>
 
 using namespace KSieveUi;
 
@@ -38,7 +41,7 @@ static const char selectMultipleHeaders[] = I18N_NOOP("Select multiple headers..
 SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Headers"));
+    setWindowTitle(i18nc("@title:window", "Headers"));
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
@@ -64,11 +67,12 @@ SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
 
     QHBoxLayout *hbox = new QHBoxLayout;
 
-    mNewHeader = new KLineEdit(this);
+    mNewHeader = new QLineEdit(this);
+    new KPIM::LineEditCatchReturnKey(mNewHeader, this);
     mNewHeader->setObjectName(QStringLiteral("newheader"));
     mNewHeader->setClearButtonEnabled(true);
-    mNewHeader->setTrapReturnKey(true);
-    connect(mNewHeader, &KLineEdit::returnPressed, this, &SelectHeadersDialog::slotAddNewHeader);
+    //mNewHeader->setTrapReturnKey(true);
+    connect(mNewHeader, &QLineEdit::returnPressed, this, &SelectHeadersDialog::slotAddNewHeader);
     mNewHeader->setClearButtonEnabled(true);
 
     mAddNewHeader = new QPushButton(this);
@@ -77,7 +81,7 @@ SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
     mAddNewHeader->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     mAddNewHeader->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
     connect(mAddNewHeader, &QPushButton::clicked, this, &SelectHeadersDialog::slotAddNewHeader);
-    connect(mNewHeader, &KLineEdit::textChanged, this, &SelectHeadersDialog::slotNewHeaderTextChanged);
+    connect(mNewHeader, &QLineEdit::textChanged, this, &SelectHeadersDialog::slotNewHeaderTextChanged);
     hbox->addWidget(mNewHeader);
     hbox->addWidget(mAddNewHeader);
 
