@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@
 
 #include <QListWidget>
 
-class KLineEdit;
+class QLineEdit;
 class QPushButton;
 namespace KSieveUi {
 class SelectHeadersWidget : public QListWidget
@@ -61,7 +61,7 @@ private:
     void readConfig();
     void writeConfig();
     SelectHeadersWidget *mListWidget = nullptr;
-    KLineEdit *mNewHeader = nullptr;
+    QLineEdit *mNewHeader = nullptr;
     QPushButton *mAddNewHeader = nullptr;
 };
 
@@ -72,7 +72,7 @@ public:
     explicit SelectHeaderTypeComboBox(bool onlyEnvelopType = false, QWidget *parent = nullptr);
     ~SelectHeaderTypeComboBox();
 
-    QString code() const;
+    Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &code);
 
 Q_SIGNALS:
