@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,7 +21,7 @@
 #define SELECTRELATIONALMATCHTYPE_H
 
 #include <QWidget>
-class KComboBox;
+class QComboBox;
 namespace KSieveUi {
 class SelectRelationalMatchType : public QWidget
 {
@@ -38,8 +38,8 @@ Q_SIGNALS:
 
 private:
     void initialize();
-    KComboBox *mType = nullptr;
-    KComboBox *mMatch = nullptr;
+    QComboBox *mType = nullptr;
+    QComboBox *mMatch = nullptr;
 };
 }
 
