@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,16 +25,16 @@
 #include "sieveeditorgraphicalmodewidget.h"
 #include "sieveconditions/sieveconditionlist.h"
 #include "sieveconditions/sievecondition.h"
-#include <PimCommon/MinimumComboBox>
 
 #include <QPushButton>
 #include <KLocalizedString>
 #include <QIcon>
+#include <QComboBox>
+#include <QPointer>
 
 #include <QGridLayout>
 #include <QLabel>
 #include <QWhatsThis>
-#include "libksieve_debug.h"
 #include "sievescriptdescriptiondialog.h"
 
 using namespace KSieveUi;
@@ -68,7 +68,7 @@ void SieveConditionWidget::setFilterCondition(QWidget *widget)
     }
 }
 
-void SieveConditionWidget::generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop)
+void SieveConditionWidget::generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop)
 {
     Q_UNUSED(inForEveryPartLoop);
     const int index = mComboBox->currentIndex();
@@ -77,8 +77,8 @@ void SieveConditionWidget::generatedScript(QString &script, QStringList &require
         QWidget *currentWidget = mLayout->itemAtPosition(1, 3)->widget();
         const QStringList lstRequires = widgetCondition->needRequires(currentWidget);
         for (const QString &r : lstRequires) {
-            if (!requires.contains(r)) {
-                requires.append(r);
+            if (!required.contains(r)) {
+                required.append(r);
             }
         }
         script += mConditionList.at(mComboBox->currentIndex())->code(currentWidget) + QLatin1Char('\n');
@@ -90,7 +90,8 @@ void SieveConditionWidget::initWidget()
     mLayout = new QGridLayout(this);
     mLayout->setContentsMargins(0, 0, 0, 0);
 
-    mComboBox = new PimCommon::MinimumComboBox;
+    mComboBox = new QComboBox;
+    mComboBox->setMinimumWidth(50);
     mComboBox->setEditable(false);
 
     const QList<KSieveUi::SieveCondition *> list = KSieveUi::SieveConditionList::conditionList(mSieveGraphicalModeWidget);
@@ -129,7 +130,7 @@ void SieveConditionWidget::initWidget()
 
     mComboBox->addItem(QLatin1String(""));
     mLayout->addWidget(mComboBox, 1, 2);
-    connect(mComboBox, QOverload<int>::of(&PimCommon::MinimumComboBox::activated), this, &SieveConditionWidget::slotConditionChanged);
+    connect(mComboBox, QOverload<int>::of(&QComboBox::activated), this, &SieveConditionWidget::slotConditionChanged);
 
     mComboBox->setMaxCount(mComboBox->count());
     mComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
@@ -311,7 +312,7 @@ QWidget *SieveConditionWidgetLister::createWidget(QWidget *parent)
     return w;
 }
 
-void SieveConditionWidgetLister::generatedScript(QString &script, int &numberOfCondition, QStringList &requires, bool inForEveryPartLoop)
+void SieveConditionWidgetLister::generatedScript(QString &script, int &numberOfCondition, QStringList &requireModules, bool inForEveryPartLoop)
 {
     const QList<QWidget *> widgetList = widgets();
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
@@ -320,7 +321,7 @@ void SieveConditionWidgetLister::generatedScript(QString &script, int &numberOfC
     for (; wIt != wEnd; ++wIt) {
         QString condition;
         SieveConditionWidget *w = qobject_cast<SieveConditionWidget *>(*wIt);
-        w->generatedScript(condition, requires, inForEveryPartLoop);
+        w->generatedScript(condition, requireModules, inForEveryPartLoop);
         if (!condition.isEmpty()) {
             if (!wasFirst) {
                 if (inForEveryPartLoop) {
@@ -345,8 +346,8 @@ void SieveConditionWidgetLister::loadTest(QXmlStreamReader &element, bool notCon
     if (notCondition) {
         element.readNextStartElement();
     }
-    if (element.attributes().hasAttribute(QStringLiteral("name"))) {
-        const QString conditionName = element.attributes().value(QStringLiteral("name")).toString();
+    if (element.attributes().hasAttribute(QLatin1String("name"))) {
+        const QString conditionName = element.attributes().value(QLatin1String("name")).toString();
         SieveConditionWidget *w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
         w->setCondition(conditionName, element, notCondition, error);
     }
@@ -370,8 +371,8 @@ void SieveConditionWidgetLister::loadScript(QXmlStreamReader &element, bool uniq
                 while (element.readNextStartElement()) {
                     const QStringRef testTagName = element.name();
                     if (testTagName == QLatin1String("test")) {
-                        if (element.attributes().hasAttribute(QStringLiteral("name"))) {
-                            QString conditionName = element.attributes().value(QStringLiteral("name")).toString();
+                        if (element.attributes().hasAttribute(QLatin1String("name"))) {
+                            QString conditionName = element.attributes().value(QLatin1String("name")).toString();
                             if (firstCondition) {
                                 firstCondition = false;
                             } else {
@@ -381,8 +382,8 @@ void SieveConditionWidgetLister::loadScript(QXmlStreamReader &element, bool uniq
                             if (conditionName == QLatin1String("not")) {
                                 notCondition = true;
                                 element.readNextStartElement();
-                                if (element.attributes().hasAttribute(QStringLiteral("name"))) {
-                                    conditionName = element.attributes().value(QStringLiteral("name")).toString();
+                                if (element.attributes().hasAttribute(QLatin1String("name"))) {
+                                    conditionName = element.attributes().value(QLatin1String("name")).toString();
                                 }
                                 w->setCondition(conditionName, element, notCondition, error);
                                 element.skipCurrentElement();
