@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -78,11 +78,11 @@ void SieveForEveryPartWidget::slotHelp()
     QWhatsThis::showText(QCursor::pos(), fullWhatsThis, mHelpButton);
 }
 
-void SieveForEveryPartWidget::generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop)
+void SieveForEveryPartWidget::generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop)
 {
     Q_UNUSED(inForEveryPartLoop);
     if (mForLoop->isChecked()) {
-        requires << QStringLiteral("foreverypart");
+        required << QStringLiteral("foreverypart");
         const QString loopName = mName->text();
         if (loopName.isEmpty()) {
             script += QStringLiteral("foreverypart {");
