@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,7 +22,7 @@
 
 #include "sievewidgetpageabstract.h"
 #include <Libkdepim/KWidgetLister>
-#include <KComboBox>
+#include <QComboBox>
 
 class QPushButton;
 class QGridLayout;
@@ -31,7 +31,7 @@ class QXmlStreamReader;
 namespace KSieveUi {
 class SieveHelpButton;
 class IncludeFileLineEdit;
-class SieveIncludeLocation : public KComboBox
+class SieveIncludeLocation : public QComboBox
 {
     Q_OBJECT
 public:
