@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@
 class QRadioButton;
 class QGroupBox;
 class QAbstractButton;
-class KComboBox;
+class QComboBox;
 class QPushButton;
 class QXmlStreamReader;
 
@@ -46,13 +46,13 @@ public:
     };
 
     explicit SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent = nullptr);
-    ~SieveScriptBlockWidget();
+    ~SieveScriptBlockWidget() override;
 
     void setPageType(PageType type) override;
 
-    void generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop) override;
+    void generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop) override;
 
-    MatchCondition matchCondition() const;
+    Q_REQUIRED_RESULT MatchCondition matchCondition() const;
 
     void loadScript(QXmlStreamReader &element, bool onlyActions, QString &error);
 
@@ -73,7 +73,7 @@ private:
     QRadioButton *mMatchAll = nullptr;
     QRadioButton *mMatchAny = nullptr;
     QRadioButton *mAllMessageRBtn = nullptr;
-    KComboBox *mNewBlockType = nullptr;
+    QComboBox *mNewBlockType = nullptr;
     QPushButton *mAddBlockType = nullptr;
 };
 }
