@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,6 +35,7 @@
 #include <QVBoxLayout>
 #include <QListWidget>
 #include <QPointer>
+#include <QMenu>
 #include "libksieve_debug.h"
 
 namespace {
@@ -98,7 +99,12 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     : QGroupBox(title, parent)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
+    layout->setObjectName(QStringLiteral("layout"));
     mSieveListScript = new QListWidget(this);
+    mSieveListScript->setObjectName(QStringLiteral("mSieveListScript"));
+    mSieveListScript->setDragDropMode(QAbstractItemView::InternalMove);
+    mSieveListScript->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(mSieveListScript, &QListWidget::customContextMenuRequested, this, &SieveScriptListBox::slotCustomMenuRequested);
     layout->addWidget(mSieveListScript);
 
     //----------- the first row of buttons
@@ -187,6 +193,26 @@ SieveScriptListBox::~SieveScriptListBox()
 {
 }
 
+void SieveScriptListBox::slotCustomMenuRequested(const QPoint &pos)
+{
+    QMenu menu(this);
+    QAction *newScriptAction = menu.addAction(i18nc("@action:inmenu", "New Script"));
+    newScriptAction->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
+    connect(newScriptAction, &QAction::triggered, this, &SieveScriptListBox::slotNew);
+
+    if (mSieveListScript->itemAt(pos)) {
+        QAction *renameScriptAction = menu.addAction(i18nc("@action:inmenu", "Rename Script"));
+        renameScriptAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
+        connect(renameScriptAction, &QAction::triggered, this, &SieveScriptListBox::slotRename);
+
+        menu.addSeparator();
+        QAction *deleteScriptAction = menu.addAction(i18nc("@action:inmenu", "Delete Script"));
+        deleteScriptAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
+        connect(deleteScriptAction, &QAction::triggered, this, &SieveScriptListBox::slotDelete);
+    }
+    menu.exec(mapToGlobal(pos));
+}
+
 void SieveScriptListBox::setSieveEditorGraphicalModeWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget)
 {
     mSieveGraphicalModeWidget = graphicalModeWidget;
@@ -233,7 +259,7 @@ SieveScriptPage *SieveScriptListBox::createNewScript(const QString &newName, con
 
 void SieveScriptListBox::slotNew()
 {
-    const QString newName = QInputDialog::getText(this, i18n("New Script"), i18n("Add new name:"));
+    const QString newName = QInputDialog::getText(this, i18nc("@title:window", "New Script"), i18n("New script name:"));
     if (!newName.trimmed().isEmpty()) {
         createNewScript(newName);
         Q_EMIT valueChanged();
@@ -244,7 +270,8 @@ void SieveScriptListBox::slotDelete()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        if (KMessageBox::warningYesNo(this, i18n("Do you want to delete \"%1\" script?", item->text()), i18n("Delete script")) == KMessageBox::Yes) {
+        if (KMessageBox::warningYesNo(this, i18n("Do you want to delete \"%1\" script?", item->text()),
+                                      i18nc("@title:window", "Delete Script")) == KMessageBox::Yes) {
             SieveScriptListItem *itemScript = static_cast<SieveScriptListItem *>(item);
             Q_EMIT removePage(itemScript->scriptPage());
             delete item;
@@ -259,7 +286,7 @@ void SieveScriptListBox::slotRename()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        QString newName = QInputDialog::getText(this, i18n("Rename"), i18n("Add new name:"), QLineEdit::Normal, item->text());
+        QString newName = QInputDialog::getText(this, i18nc("@title:window", "Rename Script"), i18n("New name for the script:"), QLineEdit::Normal, item->text());
         newName = newName.trimmed();
         if (!newName.isEmpty()) {
             item->setText(newName);
@@ -339,7 +366,7 @@ void SieveScriptListBox::slotUp()
     }
 }
 
-QString SieveScriptListBox::generatedScript(QString &requireModules) const
+QString SieveScriptListBox::generatedScript(QStringList &requireModules) const
 {
     QString resultScript;
     QStringList lstRequires;
@@ -360,7 +387,7 @@ QString SieveScriptListBox::generatedScript(QString &requireModules) const
     for (const QString &r : qAsConst(lstRequires)) {
         if (!endRequires.contains(r)) {
             endRequires.append(r);
-            requireModules += QStringLiteral("require \"%1\";\n").arg(r);
+            requireModules += QStringLiteral("require \"%1\";").arg(r);
         }
     }
 
