@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,7 +19,7 @@
 
 #include "sievescriptparsingerrordialog.h"
 #include <PimCommon/PimUtil>
-#include "kpimtextedit/richtexteditorwidget.h"
+#include <KPIMTextEdit/RichTextEditorWidget>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -33,7 +33,7 @@ using namespace KSieveUi;
 SieveScriptParsingErrorDialog::SieveScriptParsingErrorDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Sieve Parsing Error"));
+    setWindowTitle(i18nc("@title:window", "Sieve Parsing Error"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     mTextEdit = new KPIMTextEdit::RichTextEditorWidget(this);
