@@ -12,8 +12,8 @@
 */
 
 #include "sievedebugdialog.h"
-#include "kpimtextedit/plaintexteditorwidget.h"
-#include "kpimtextedit/plaintexteditor.h"
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <KPIMTextEdit/PlainTextEditor>
 #include "util/util_p.h"
 
 #include "libksieve_debug.h"
@@ -36,7 +36,7 @@ SieveDebugDialog::SieveDebugDialog(SieveImapPasswordProvider *passwordProvider,
     : QDialog(parent)
     , mPasswordProvider(passwordProvider)
 {
-    setWindowTitle(i18n("Sieve Diagnostics"));
+    setWindowTitle(i18nc("@title:window", "Sieve Diagnostics"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     // Collect all accounts
@@ -154,12 +154,12 @@ void SieveDebugDialog::slotDiagNextScript()
         return;
     }
 
-    QString scriptFile = mScriptList.first();
+    QString scriptFile = mScriptList.constFirst();
     mScriptList.pop_front();
 
     mEdit->editor()->appendPlainText(i18n("Contents of script '%1':\n", scriptFile));
 
-    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(mResourceIdentifier.first(), mPasswordProvider);
+    const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(mResourceIdentifier.constFirst(), mPasswordProvider);
     mUrl = info.sieveUrl;
 
     mUrl = mUrl.adjusted(QUrl::RemoveFilename);
@@ -173,9 +173,19 @@ void SieveDebugDialog::slotDiagNextScript()
 void SieveDebugDialog::slotGetScript(KManageSieve::SieveJob *job, bool success, const QString &script, bool active)
 {
     qCDebug(LIBKSIEVE_LOG) << "( ??," << success
-                           << ", ?," << active << ")" << endl
-                           << "script:" << endl
-                           << script;
+                           << ", ?," << active << ")"
+                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+        << endl
+                          #else
+        << Qt::endl
+                          #endif
+        << "script:"
+                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+        << endl
+                          #else
+        << Qt::endl
+                          #endif
+        << script;
     mSieveJob = nullptr; // job deletes itself after returning from this slot!
 
     if (!success) {
