@@ -1,4 +1,4 @@
-/* Copyright (C) 2013-2015 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,7 +19,6 @@
 #include "sieveeditortextmodewidget.h"
 #include "templates/sievetemplatewidget.h"
 #include "autocreatescripts/autocreatescriptdialog.h"
-#include "editor/sieveinfowidget.h"
 #include "editor/sievetextedit.h"
 #include "editor/warningwidget/sieveeditorwarning.h"
 #include "editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
@@ -29,13 +28,13 @@
 #include "scriptsparsing/xmlprintingscriptbuilder.h"
 #include "scriptsparsing/parsingresultdialog.h"
 
-#include "kpimtextedit/plaintexteditfindbar.h"
-#include "kpimtextedit/plaintexteditorwidget.h"
-#include "kpimtextedit/texttospeechwidget.h"
-#include "kpimtextedit/textgotolinewidget.h"
+#include <KPIMTextEdit/PlainTextEditFindBar>
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <KPIMTextEdit/TextToSpeechWidget>
+#include <KPIMTextEdit/TextGotoLineWidget>
 #include "KSplitterCollapserButton"
-#include "sieveeditorhelphtmlwidget.h"
-#include "kpimtextedit/slidecontainer.h"
+#include "webengine/sieveeditorhelphtmlwidget.h"
+#include <KPIMTextEdit/SlideContainer>
 
 #include <ksieve/parser.h>
 #include <ksieve/error.h>
@@ -44,24 +43,27 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
+#include <KMessageBox>
 
 #include <QSplitter>
 #include <QShortcut>
 #include <QPointer>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <QDebug>
+#include <QPrinter>
+#include <QPrintDialog>
+#include <PimCommon/KPimPrintPreviewDialog>
 
 #include <errno.h>
+#include <memory>
 
 using namespace KSieveUi;
 
 SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     : SieveEditorAbstractWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout;
-    lay->setMargin(0);
-    setLayout(lay);
+    QVBoxLayout *lay = new QVBoxLayout(this);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     mMainSplitter = new QSplitter;
     mMainSplitter->setOrientation(Qt::Vertical);
@@ -72,39 +74,41 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     //
     mSieveTemplateWidget = new SieveTemplateWidget(i18n("Sieve Template:"));
 
-    mSieveInfo = new SieveInfoWidget;
-
-    mExtraSplitter = new QSplitter;
-    mExtraSplitter->setOrientation(Qt::Vertical);
-
-    mExtraSplitter->addWidget(mSieveTemplateWidget);
-    mExtraSplitter->addWidget(mSieveInfo);
-    mExtraSplitter->setChildrenCollapsible(false);
-
     QWidget *textEditWidget = new QWidget;
     QVBoxLayout *textEditLayout = new QVBoxLayout;
-    textEditLayout->setMargin(0);
+    textEditLayout->setContentsMargins(0, 0, 0, 0);
+
+    mEditorWidget = new QWidget;
+    QVBoxLayout *editorWidgetLayout = new QVBoxLayout;
+    editorWidgetLayout->setContentsMargins(0, 0, 0, 0);
+    mEditorWidget->setLayout(editorWidgetLayout);
 
     mTabWidget = new SieveEditorTabWidget;
+    connect(mTabWidget, &SieveEditorTabWidget::currentChanged, this, &SieveEditorTextModeWidget::sieveEditorTabCurrentChanged);
+    connect(mTabWidget, &SieveEditorTabWidget::copyAvailable, this, &SieveEditorTextModeWidget::copyAvailable);
     mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
-    textEditLayout->addWidget(mTextToSpeechWidget);
+    editorWidgetLayout->addWidget(mTextToSpeechWidget);
 
     mTextEdit = new SieveTextEdit;
+    editorWidgetLayout->addWidget(mTextEdit);
     connect(mTextEdit, &SieveTextEdit::textChanged, this, &SieveEditorTextModeWidget::valueChanged);
-    mTabWidget->addTab(mTextEdit, i18n("Editor"));
+    mTabWidget->addTab(mEditorWidget, i18n("Editor"));
     mTabWidget->tabBar()->hide();
     textEditLayout->addWidget(mTabWidget);
     connect(mTextEdit, &SieveTextEdit::openHelp, mTabWidget, &SieveEditorTabWidget::slotAddHelpPage);
     connect(mTextEdit, &SieveTextEdit::say, mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
+    connect(mTextEdit, &SieveTextEdit::editRule, this, &SieveEditorTextModeWidget::slotEditRule);
+    connect(mTextEdit, &SieveTextEdit::insertRule, this, &SieveEditorTextModeWidget::slotInsertRule);
 
     mGotoLineSliderContainer = new KPIMTextEdit::SlideContainer(this);
     mGoToLine = new KPIMTextEdit::TextGoToLineWidget;
     mGoToLine->hide();
     mGotoLineSliderContainer->setContent(mGoToLine);
-    textEditLayout->addWidget(mGotoLineSliderContainer);
+    editorWidgetLayout->addWidget(mGotoLineSliderContainer);
     connect(mGoToLine, &KPIMTextEdit::TextGoToLineWidget::hideGotoLine, mGotoLineSliderContainer, &KPIMTextEdit::SlideContainer::slideOut);
 
     connect(mGoToLine, &KPIMTextEdit::TextGoToLineWidget::moveToLine, this, &SieveEditorTextModeWidget::slotGoToLine);
+    connect(mTextEdit, &SieveTextEdit::blockCountChanged, mGoToLine, &KPIMTextEdit::TextGoToLineWidget::slotBlockCountChanged);
 
     mSliderContainer = new KPIMTextEdit::SlideContainer(this);
     mFindBar = new KPIMTextEdit::PlainTextEditFindBar(mTextEdit, textEditWidget);
@@ -112,21 +116,21 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     connect(mFindBar, &KPIMTextEdit::TextEditFindBarBase::hideFindBar, mSliderContainer, &KPIMTextEdit::SlideContainer::slideOut);
     connect(mFindBar, &KPIMTextEdit::TextEditFindBarBase::displayMessageIndicator, mTextEdit, &KPIMTextEdit::PlainTextEditor::slotDisplayMessageIndicator);
     mSliderContainer->setContent(mFindBar);
-    textEditLayout->addWidget(mSliderContainer);
+    editorWidgetLayout->addWidget(mSliderContainer);
 
     mSieveEditorWarning = new SieveEditorWarning;
-    textEditLayout->addWidget(mSieveEditorWarning);
+    editorWidgetLayout->addWidget(mSieveEditorWarning);
 
     mSieveParsingWarning = new SieveEditorParsingMissingFeatureWarning(SieveEditorParsingMissingFeatureWarning::TextEditor);
     connect(mSieveParsingWarning, &SieveEditorParsingMissingFeatureWarning::switchToGraphicalMode, this, &SieveEditorTextModeWidget::switchToGraphicalMode);
-    textEditLayout->addWidget(mSieveParsingWarning);
+    editorWidgetLayout->addWidget(mSieveParsingWarning);
 
     textEditWidget->setLayout(textEditLayout);
 
     mTemplateSplitter->addWidget(textEditWidget);
-    mTemplateSplitter->addWidget(mExtraSplitter);
+    mTemplateSplitter->addWidget(mSieveTemplateWidget);
     mTemplateSplitter->setCollapsible(0, false);
-    new KSplitterCollapserButton(mExtraSplitter, mTemplateSplitter);
+    new KSplitterCollapserButton(mSieveTemplateWidget, mTemplateSplitter);
 
     connect(mSieveTemplateWidget, &SieveTemplateWidget::insertTemplate, mTextEdit, &SieveTextEdit::insertPlainText);
 
@@ -137,6 +141,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     mDebugTextEdit = new KPIMTextEdit::PlainTextEditorWidget;
     mDebugTextEdit->editor()->setSearchSupport(false);
     mDebugTextEdit->editor()->setReadOnly(true);
+    mDebugTextEdit->editor()->setPlaceholderText(i18n("Show result from \"check syntax\""));
     mMainSplitter->addWidget(mTemplateSplitter);
     mMainSplitter->addWidget(mDebugTextEdit);
     mMainSplitter->setChildrenCollapsible(false);
@@ -161,18 +166,25 @@ void SieveEditorTextModeWidget::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
     group.writeEntry("mainSplitter", mMainSplitter->sizes());
-    group.writeEntry("extraSplitter", mExtraSplitter->sizes());
     group.writeEntry("templateSplitter", mTemplateSplitter->sizes());
 }
 
+QStringList SieveEditorTextModeWidget::sieveCapabilities() const
+{
+    return mSieveCapabilities;
+}
+
+SieveEditorTabWidget *SieveEditorTextModeWidget::tabWidget() const
+{
+    return mTabWidget;
+}
+
 void SieveEditorTextModeWidget::readConfig()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
-    QList<int> size;
-    size << 400 << 100;
+    const QList<int> size = {400, 100};
 
     mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
-    mExtraSplitter->setSizes(group.readEntry("extraSplitter", size));
     mTemplateSplitter->setSizes(group.readEntry("templateSplitter", size));
 }
 
@@ -198,36 +210,105 @@ void SieveEditorTextModeWidget::slotShowGoToLine()
 
 void SieveEditorTextModeWidget::generateXml()
 {
-#if !defined(NDEBUG)
     const QByteArray script = mTextEdit->toPlainText().toUtf8();
     KSieve::Parser parser(script.begin(),
                           script.begin() + script.length());
-    KSieveUi::XMLPrintingScriptBuilder psb;
+    KSieveUi::XMLPrintingScriptBuilder psb(2);
     parser.setScriptBuilder(&psb);
     const bool result = parser.parse();
     QPointer<ParsingResultDialog> dlg = new ParsingResultDialog(this);
     if (result) {
-        dlg->setResultParsing(psb.toDom().toString());
+        dlg->setResultParsing(psb.result());
     } else {
         dlg->setResultParsing(i18n("Error during parsing"));
     }
     dlg->exec();
     delete dlg;
-#endif
 }
 
-void SieveEditorTextModeWidget::autoGenerateScripts()
+void SieveEditorTextModeWidget::slotEditRule(const QString &selectedText)
+{
+    const QByteArray script = selectedText.toUtf8();
+    KSieve::Parser parser(script.begin(),
+                          script.begin() + script.length());
+    KSieveUi::XMLPrintingScriptBuilder psb(2);
+    parser.setScriptBuilder(&psb);
+    const bool result = parser.parse();
+    if (result) {
+        QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
+        dlg->setSieveCapabilities(mSieveCapabilities);
+        dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
+        dlg->setListOfIncludeFile(mListOfIncludeFile);
+        QString error;
+        //qDebug() << " psb.result()" << psb.result();
+        dlg->loadScript(psb.result(), error);
+        if (dlg->exec()) {
+            QStringList requireModules;
+            const QString newScript = dlg->script(requireModules);
+            const QStringList needToAddRequire = insertNecessaryRequires(requireModules);
+            mTextEdit->insertPlainText(newScript);
+            insertRequires(needToAddRequire);
+        }
+        delete dlg;
+    } else {
+        KMessageBox::error(this, i18n("Selected text is not a full sieve script"), i18n("Parsing error"));
+    }
+}
+
+void SieveEditorTextModeWidget::insertRequires(const QStringList &needToAddRequire)
+{
+    if (!needToAddRequire.isEmpty()) {
+        QTextCursor textCursor = mTextEdit->textCursor();
+        textCursor.movePosition(QTextCursor::MoveOperation::Start);
+        textCursor.insertText(needToAddRequire.join(QLatin1Char('\n')) + QLatin1Char('\n'));
+    }
+}
+
+QStringList SieveEditorTextModeWidget::insertNecessaryRequires(const QStringList &requireModules)
+{
+    QStringList needToAddRequire;
+    const QString plainText = mTextEdit->toPlainText();
+    for (const QString &module : qAsConst(requireModules)) {
+        if (!plainText.contains(module)) {
+            needToAddRequire.append(module);
+        }
+    }
+    return needToAddRequire;
+}
+
+void SieveEditorTextModeWidget::slotInsertRule()
 {
     QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
     dlg->setSieveCapabilities(mSieveCapabilities);
+    dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
+    dlg->setListOfIncludeFile(mListOfIncludeFile);
     if (dlg->exec()) {
-        QString requires;
-        const QString script = dlg->script(requires);
+        QStringList requireModules;
+        const QString newScript = dlg->script(requireModules);
+        const QStringList needToAddRequire = insertNecessaryRequires(requireModules);
+        mTextEdit->insertPlainText(newScript);
+        insertRequires(needToAddRequire);
+    }
+    delete dlg;
+}
+
+void SieveEditorTextModeWidget::createRulesGraphically()
+{
+    QPointer<AutoCreateScriptDialog> dlg = new AutoCreateScriptDialog(this);
+    dlg->setSieveCapabilities(mSieveCapabilities);
+    dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
+    dlg->setListOfIncludeFile(mListOfIncludeFile);
+    if (dlg->exec()) {
+        QStringList requireModules;
+        const QString script = dlg->script(requireModules);
+        const QStringList needToAddRequire = insertNecessaryRequires(requireModules);
         QString newPlainText = mTextEdit->toPlainText() + script;
-        if (!requires.isEmpty()) {
-            newPlainText.prepend(requires + QLatin1Char('\n'));
+        if (!needToAddRequire.isEmpty()) {
+            newPlainText.prepend(requireModules.join(QLatin1Char('\n')) + QLatin1Char('\n'));
         }
-        mTextEdit->setPlainText(newPlainText);
+        mTextEdit->selectAll();
+
+        mTextEdit->insertPlainText(newPlainText);
     }
     delete dlg;
 }
@@ -244,53 +325,89 @@ void SieveEditorTextModeWidget::replace()
 
 void SieveEditorTextModeWidget::undo()
 {
-    mTextEdit->undo();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->undo();
+    }
 }
 
 void SieveEditorTextModeWidget::redo()
 {
-    mTextEdit->redo();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->redo();
+    }
 }
 
 void SieveEditorTextModeWidget::paste()
 {
-    mTextEdit->paste();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->paste();
+    }
 }
 
 void SieveEditorTextModeWidget::cut()
 {
-    mTextEdit->cut();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->cut();
+    }
 }
 
 void SieveEditorTextModeWidget::copy()
 {
-    mTextEdit->copy();
+    QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->copy();
+    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+        page->copy();
+    }
 }
 
 void SieveEditorTextModeWidget::selectAll()
 {
-    mTextEdit->selectAll();
+    QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        mTextEdit->selectAll();
+    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+        page->selectAll();
+    }
 }
 
 bool SieveEditorTextModeWidget::isUndoAvailable() const
 {
-    return mTextEdit->document()->isUndoAvailable();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        return mTextEdit->document()->isUndoAvailable();
+    }
+    return false;
 }
 
 bool SieveEditorTextModeWidget::isRedoAvailable() const
 {
-    return mTextEdit->document()->isRedoAvailable();
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        return mTextEdit->document()->isRedoAvailable();
+    }
+    return false;
 }
 
 bool SieveEditorTextModeWidget::hasSelection() const
 {
-    return mTextEdit->textCursor().hasSelection();
+    QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        return mTextEdit->textCursor().hasSelection();
+    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+        return page->hasSelection();
+    }
+    return false;
 }
 
 void SieveEditorTextModeWidget::zoomIn()
 {
     QWidget *w = mTabWidget->currentWidget();
-    if (w == mTextEdit) {
+    if (w == mEditorWidget) {
         mTextEdit->zoomIn();
     } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomIn();
@@ -300,7 +417,7 @@ void SieveEditorTextModeWidget::zoomIn()
 void SieveEditorTextModeWidget::zoomOut()
 {
     QWidget *w = mTabWidget->currentWidget();
-    if (w == mTextEdit) {
+    if (w == mEditorWidget) {
         mTextEdit->zoomOut();
     } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomOut();
@@ -312,6 +429,39 @@ bool SieveEditorTextModeWidget::isWordWrap() const
     return mTextEdit->isWordWrap();
 }
 
+void SieveEditorTextModeWidget::print()
+{
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        QPrinter printer;
+
+        std::unique_ptr<QPrintDialog> dlg(new QPrintDialog(&printer));
+
+        bool restoreSpellCheck = mTextEdit->checkSpellingEnabled();
+        mTextEdit->setCheckSpellingEnabled(false);
+        if (dlg && dlg->exec() == QDialog::Accepted) {
+            mTextEdit->print(&printer);
+        }
+        mTextEdit->setCheckSpellingEnabled(restoreSpellCheck);
+    }
+}
+
+void SieveEditorTextModeWidget::printPreview()
+{
+    const QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        bool restoreSpellCheck = mTextEdit->checkSpellingEnabled();
+        mTextEdit->setCheckSpellingEnabled(false);
+        QPointer<PimCommon::KPimPrintPreviewDialog> previewdlg = new PimCommon::KPimPrintPreviewDialog(this);
+        connect(previewdlg.data(), &QPrintPreviewDialog::paintRequested, this, [this](QPrinter *printer) {
+            mTextEdit->print(printer);
+        });
+        previewdlg->exec();
+        delete previewdlg;
+        mTextEdit->setCheckSpellingEnabled(restoreSpellCheck);
+    }
+}
+
 void SieveEditorTextModeWidget::wordWrap(bool state)
 {
     mTextEdit->wordWrap(state);
@@ -320,7 +470,7 @@ void SieveEditorTextModeWidget::wordWrap(bool state)
 void SieveEditorTextModeWidget::zoomReset()
 {
     QWidget *w = mTabWidget->currentWidget();
-    if (w == mTextEdit) {
+    if (w == mEditorWidget) {
         mTextEdit->slotZoomReset();
     } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->resetZoom();
@@ -329,13 +479,18 @@ void SieveEditorTextModeWidget::zoomReset()
 
 void SieveEditorTextModeWidget::slotFind()
 {
-    if (mTextEdit->textCursor().hasSelection()) {
-        mFindBar->setText(mTextEdit->textCursor().selectedText());
+    QWidget *w = mTabWidget->currentWidget();
+    if (w == mEditorWidget) {
+        if (mTextEdit->textCursor().hasSelection()) {
+            mFindBar->setText(mTextEdit->textCursor().selectedText());
+        }
+        mTextEdit->moveCursor(QTextCursor::Start);
+        mFindBar->showFind();
+        mSliderContainer->slideIn();
+        mFindBar->focusAndSetCursor();
+    } else if (SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+        page->find();
     }
-    mTextEdit->moveCursor(QTextCursor::Start);
-    mFindBar->showFind();
-    mSliderContainer->slideIn();
-    mFindBar->focusAndSetCursor();
 }
 
 void SieveEditorTextModeWidget::slotReplace()
@@ -355,7 +510,8 @@ QString SieveEditorTextModeWidget::currentscript()
 
 void SieveEditorTextModeWidget::setImportScript(const QString &script)
 {
-    mTextEdit->setPlainText(script);
+    mTextEdit->selectAll();
+    mTextEdit->insertPlainText(script);
 }
 
 void SieveEditorTextModeWidget::slotTextChanged()
@@ -369,9 +525,14 @@ QString SieveEditorTextModeWidget::script() const
     return mTextEdit->toPlainText();
 }
 
-void SieveEditorTextModeWidget::setScript(const QString &script)
+void SieveEditorTextModeWidget::setScript(const QString &script, bool clearUndoRedo)
 {
-    mTextEdit->setPlainText(script);
+    if (clearUndoRedo) {
+        mTextEdit->setPlainText(script);
+    } else {
+        mTextEdit->selectAll();
+        mTextEdit->insertPlainText(script);
+    }
 }
 
 void SieveEditorTextModeWidget::setDebugScript(const QString &debug)
@@ -380,12 +541,16 @@ void SieveEditorTextModeWidget::setDebugScript(const QString &debug)
     mDebugTextEdit->editor()->appendHtml(debug);
 }
 
+void SieveEditorTextModeWidget::setListOfIncludeFile(const QStringList &listOfIncludeFile)
+{
+    mListOfIncludeFile = listOfIncludeFile;
+}
+
 void SieveEditorTextModeWidget::setSieveCapabilities(const QStringList &capabilities)
 {
     mSieveCapabilities = capabilities;
     mTextEdit->setSieveCapabilities(mSieveCapabilities);
     mSieveTemplateWidget->setSieveCapabilities(mSieveCapabilities);
-    mSieveInfo->setServerInfo(capabilities);
 }
 
 void SieveEditorTextModeWidget::showEditorWarning()
@@ -470,7 +635,19 @@ void SieveEditorTextModeWidget::debugSieveScript()
     dlg->setScript(mTextEdit->toPlainText());
     if (dlg->exec()) {
         const QString script = dlg->script();
-        mTextEdit->setPlainText(script);
+        mTextEdit->selectAll();
+        mTextEdit->insertPlainText(script);
     }
     delete dlg;
 }
+
+bool SieveEditorTextModeWidget::isTextEditor() const
+{
+    const QWidget *w = mTabWidget->currentWidget();
+    return w == mEditorWidget;
+}
+
+bool SieveEditorTextModeWidget::printSupportEnabled() const
+{
+    return isTextEditor();
+}
