@@ -1,4 +1,4 @@
-/* Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -32,7 +32,6 @@ class TextToSpeechWidget;
 }
 
 namespace KSieveUi {
-class SieveInfoWidget;
 class SieveTextEdit;
 class SieveEditorWarning;
 class SieveEditorParsingMissingFeatureWarning;
@@ -105,6 +104,8 @@ public:
     Q_REQUIRED_RESULT SieveEditorTabWidget *tabWidget() const;
 
     void setListOfIncludeFile(const QStringList &listOfIncludeFile);
+    Q_REQUIRED_RESULT QStringList sieveCapabilities() const;
+
 Q_SIGNALS:
     void enableButtonOk(bool);
     void switchToGraphicalMode();
@@ -123,7 +124,10 @@ private:
     void slotGoToLine(int line);
     void readConfig();
     void writeConfig();
-    bool loadFromFile(const QString &filename);
+    void slotEditRule(const QString &selectedText);
+    void slotInsertRule();
+    void insertRequires(const QStringList &needToAddRequire);
+    Q_REQUIRED_RESULT QStringList insertNecessaryRequires(const QStringList &requireModules);
     QString mOriginalScript;
     QStringList mSieveCapabilities;
     QStringList mListOfIncludeFile;
@@ -131,9 +135,7 @@ private:
     KPIMTextEdit::PlainTextEditorWidget *mDebugTextEdit = nullptr;
     KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
-    SieveInfoWidget *mSieveInfo = nullptr;
     QSplitter *mMainSplitter = nullptr;
-    QSplitter *mExtraSplitter = nullptr;
     QSplitter *mTemplateSplitter = nullptr;
     SieveEditorWarning *mSieveEditorWarning = nullptr;
     SieveEditorParsingMissingFeatureWarning *mSieveParsingWarning = nullptr;
