@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,11 +19,11 @@
 #define SIEVEINFOWIDGET_H
 
 #include <QWidget>
-
+#include "ksieveui_export.h"
 class QTextEdit;
 
 namespace KSieveUi {
-class SieveInfoWidget : public QWidget
+class KSIEVEUI_EXPORT SieveInfoWidget : public QWidget
 {
     Q_OBJECT
 public:
