@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2017 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2011-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -38,6 +38,7 @@
 #include <QMenu>
 #include <QFontDatabase>
 #include <QCompleter>
+#include <QTextDocumentFragment>
 using namespace KSieveUi;
 
 class KSieveUi::SieveTextEditPrivate
@@ -122,7 +123,7 @@ int SieveTextEdit::lineNumberAreaWidth() const
         ++digits;
     }
 
-    const int space = 3 + fontMetrics().width(QLatin1Char('9')) * digits;
+    const int space = 2 + fontMetrics().boundingRect(QLatin1Char('9')).width() * digits;
     return space;
 }
 
@@ -133,8 +134,8 @@ void SieveTextEdit::lineNumberAreaPaintEvent(QPaintEvent *event)
 
     QTextBlock block = firstVisibleBlock();
     int blockNumber = block.blockNumber();
-    int top = (int)blockBoundingGeometry(block).translated(contentOffset()).top();
-    int bottom = top + (int)blockBoundingRect(block).height();
+    int top = static_cast<int>(blockBoundingGeometry(block).translated(contentOffset()).top());
+    int bottom = top + static_cast<int>(blockBoundingRect(block).height());
     while (block.isValid() && top <= event->rect().bottom()) {
         if (block.isVisible() && bottom >= event->rect().top()) {
             const QString number = QString::number(blockNumber + 1);
@@ -145,7 +146,7 @@ void SieveTextEdit::lineNumberAreaPaintEvent(QPaintEvent *event)
 
         block = block.next();
         top = bottom;
-        bottom = top + (int)blockBoundingRect(block).height();
+        bottom = top + static_cast<int>(blockBoundingRect(block).height());
         ++blockNumber;
     }
 }
@@ -258,7 +259,7 @@ void SieveTextEdit::keyPressEvent(QKeyEvent *e)
     } else if (handleShortcut(e)) {
         return;
     }
-    QPlainTextEdit::keyPressEvent(e);
+    KPIMTextEdit::PlainTextEditor::keyPressEvent(e);
     if (e->key() == Qt::Key_F1 && !textCursor().hasSelection()) {
         const QString word = selectedWord();
         const KSieveUi::SieveEditorUtil::HelpVariableName type = KSieveUi::SieveEditorUtil::strToVariableName(word);
@@ -290,6 +291,14 @@ void SieveTextEdit::addExtraMenuEntry(QMenu *menu, QPoint pos)
     }
 
     if (!textCursor().hasSelection()) {
+        if (!isReadOnly()) {
+            QAction *insertRules = new QAction(i18n("Insert Rule"), menu);
+            //editRules->setIcon(QIcon::fromTheme(QStringLiteral("help-hint")));
+            connect(insertRules, &QAction::triggered, this, &SieveTextEdit::insertRule);
+            QAction *act = menu->addSeparator();
+            menu->insertActions(menu->actions().at(0), {insertRules, act});
+        }
+
         const QString word = selectedWord(pos);
         const KSieveUi::SieveEditorUtil::HelpVariableName type = KSieveUi::SieveEditorUtil::strToVariableName(word);
         if (type != KSieveUi::SieveEditorUtil::UnknownHelp) {
@@ -304,6 +313,14 @@ void SieveTextEdit::addExtraMenuEntry(QMenu *menu, QPoint pos)
             connect(searchAction, &QAction::triggered, this, &SieveTextEdit::slotHelp);
             menu->insertAction(menu->actions().at(0), searchAction);
         }
+    } else {
+        if (!isReadOnly()) {
+            QAction *editRules = new QAction(i18n("Edit Rule"), menu);
+            //editRules->setIcon(QIcon::fromTheme(QStringLiteral("help-hint")));
+            connect(editRules, &QAction::triggered, this, &SieveTextEdit::slotEditRule);
+            QAction *act = menu->addSeparator();
+            menu->insertActions(menu->actions().at(0), {editRules, act});
+        }
     }
 }
 
@@ -316,6 +333,12 @@ QString SieveTextEdit::selectedWord(const QPoint &pos) const
     return word;
 }
 
+void SieveTextEdit::slotEditRule()
+{
+    QTextCursor textcursor = textCursor();
+    Q_EMIT editRule(textcursor.selection().toPlainText());
+}
+
 void SieveTextEdit::slotHelp()
 {
     QAction *act = qobject_cast<QAction *>(sender());
@@ -388,14 +411,18 @@ void SieveTextEdit::uncomment()
             text.remove(0, 1);
         }
         QString newText = text;
-        for (int i = 0; i < newText.length(); ++i) {
+        for (int i = 0; i < newText.length();) {
             if (newText.at(i) == QChar::ParagraphSeparator || newText.at(i) == QChar::LineSeparator) {
                 ++i;
-                if (i < text.length()) {
+                if (i < newText.length()) {
                     if (newText.at(i) == QLatin1Char('#')) {
                         newText.remove(i, 1);
+                    } else {
+                        ++i;
                     }
                 }
+            } else {
+                ++i;
             }
         }
 
