@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,8 +19,8 @@
 #include <QVBoxLayout>
 #include "editor/sievetextedit.h"
 
-#include "kpimtextedit/plaintexteditfindbar.h"
-#include "kpimtextedit/slidecontainer.h"
+#include <KPIMTextEdit/PlainTextEditFindBar>
+#include <KPIMTextEdit/SlideContainer>
 using namespace KSieveUi;
 
 class KSieveUi::SieveTextEditWidgetPrivate
