@@ -1,4 +1,4 @@
-/* Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,8 +16,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H
-#define WEBENGINEVIEWER_FINDBAR_MAILWEBENGINEVIEW_H
+#ifndef WEBENGINEVIEWER_FINDBAR_WEBENGINEVIEW_H
+#define WEBENGINEVIEWER_FINDBAR_WEBENGINEVIEW_H
 
 #include "findbarbase.h"
 #include "ksieveui_export.h"
