@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,7 +27,7 @@
 
 #include <KLocalizedString>
 #include <QPushButton>
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <KConfigGroup>
 
 #include <kmanagesieve/sievejob.h>
@@ -79,7 +79,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     : QDialog(parent)
     , d(new KSieveUi::ManageSieveScriptsDialogPrivate)
 {
-    setWindowTitle(i18n("Manage Sieve Scripts"));
+    setWindowTitle(i18nc("@title:window", "Manage Sieve Scripts"));
     setModal(false);
     setAttribute(Qt::WA_GroupLeader);
     setAttribute(Qt::WA_DeleteOnClose);
@@ -133,6 +133,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
 
 ManageSieveScriptsDialog::~ManageSieveScriptsDialog()
 {
+    disconnect(d->mTreeView, &CustomManageSieveWidget::updateButtons, this, &ManageSieveScriptsDialog::slotUpdateButtons);
     KConfigGroup group(KSharedConfig::openConfig(), "ManageSieveScriptsDialog");
     group.writeEntry("Size", size());
     // prevent QTreeWidget signals triggered by it's destructor from calling our slots
@@ -273,7 +274,7 @@ void ManageSieveScriptsDialog::slotPutResult(KManageSieve::SieveJob *job, bool s
     } else {
         //Don't add parent otherwise when there is an error it will parent to ManageSieveScriptsDialog and not editor
         KMessageBox::error(nullptr, i18n("Uploading the Sieve script failed.\n"
-                                      "The server responded:\n%1", job->errorString()), i18n("Sieve Error"));
+                                         "The server responded:\n%1", job->errorString()), i18n("Sieve Error"));
         if (d->mSieveEditor) {
             d->mSieveEditor->show();
         }
