@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,8 +19,8 @@
 
 #include "parsingresultdialog.h"
 #include <PimCommon/PimUtil>
-#include "kpimtextedit/plaintexteditorwidget.h"
-#include "kpimtextedit/plaintexteditor.h"
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <KPIMTextEdit/PlainTextEditor>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -38,7 +38,7 @@ using namespace KSieveUi;
 ParsingResultDialog::ParsingResultDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Sieve Parsing"));
+    setWindowTitle(i18nc("@title:window", "Sieve Parsing"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
