@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
 #ifndef SIEVESCRIPTDEBUGGERRESULTEDITOR_H
 #define SIEVESCRIPTDEBUGGERRESULTEDITOR_H
 
-#include <kpimtextedit/plaintexteditor.h>
+#include <KPIMTextEdit/PlainTextEditor>
 
 namespace KSieveUi {
 class SieveScriptDebuggerResultEditor : public KPIMTextEdit::PlainTextEditor
@@ -28,7 +28,7 @@ class SieveScriptDebuggerResultEditor : public KPIMTextEdit::PlainTextEditor
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerResultEditor(QWidget *parent = nullptr);
-    ~SieveScriptDebuggerResultEditor();
+    ~SieveScriptDebuggerResultEditor() override;
 
 protected:
     void addExtraMenuEntry(QMenu *menu, QPoint pos) override;
