@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -94,9 +94,16 @@ QString SieveScriptDebuggerWidget::script() const
 void SieveScriptDebuggerWidget::checkSieveTestApplication()
 {
     if (QStandardPaths::findExecutable(QStringLiteral("sieve-test")).isEmpty()) {
+        mHaveDebugApps = false;
         mStackedWidget->setCurrentWidget(mSieveNoExistingFrontEnd);
         Q_EMIT sieveTestNotFound();
     } else {
+        mHaveDebugApps = true;
         mStackedWidget->setCurrentWidget(mSieveScriptFrontEnd);
     }
 }
+
+bool SieveScriptDebuggerWidget::haveDebugApps() const
+{
+    return mHaveDebugApps;
+}
