@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,6 +26,10 @@ class QStackedWidget;
 class QLabel;
 namespace KSieveUi {
 class SieveScriptDebuggerFrontEndWidget;
+/**
+ * @brief The SieveScriptDebuggerWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KSIEVEUI_EXPORT SieveScriptDebuggerWidget : public QWidget
 {
     Q_OBJECT
@@ -34,13 +38,15 @@ public:
     ~SieveScriptDebuggerWidget();
 
     void setScript(const QString &script);
-    QString script() const;
+    Q_REQUIRED_RESULT QString script() const;
 
-    bool canAccept() const;
+    Q_REQUIRED_RESULT bool canAccept() const;
 
-    QList<int> splitterSizes() const;
+    Q_REQUIRED_RESULT QList<int> splitterSizes() const;
     void setSplitterSizes(const QList<int> &sizes);
 
+    Q_REQUIRED_RESULT bool haveDebugApps() const;
+
 Q_SIGNALS:
     void scriptTextChanged();
     void debugScriptButtonClicked();
@@ -52,6 +58,7 @@ private:
     QStackedWidget *mStackedWidget = nullptr;
     SieveScriptDebuggerFrontEndWidget *mSieveScriptFrontEnd = nullptr;
     QLabel *mSieveNoExistingFrontEnd = nullptr;
+    bool mHaveDebugApps = false;
 };
 }
 #endif // SIEVESCRIPTDEBUGGERWIDGET_H
