@@ -48,7 +48,7 @@
 #include "akonadiimapsettinginterface.h"
 
 #include <kmime/kmime_message.h>
-#include <mailtransport/transport.h>
+#include <MailTransport/Transport>
 #include <QUrlQuery>
 
 using namespace KSieveUi;
@@ -61,8 +61,7 @@ KSieveUi::Util::AccountInfo KSieveUi::Util::fullAccountInfo(const QString &ident
     return accountInfo;
 }
 
-KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName,
-                                                            std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> &interface)
+KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName, std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> &interface)
 {
     KSieveUi::Util::AccountInfo accountInfo;
     if (!interface) {
@@ -130,9 +129,9 @@ KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &ident
             accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
             query.addQueryItem(QStringLiteral("x-allow-unencrypted"), QStringLiteral("true"));
         } else if (resultSafety == QLatin1String("SSL")) {
-            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::AnySslVersion);
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::SSLorTLS);
         } else if (resultSafety == QLatin1String("STARTTLS")) {
-            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::TlsV1);
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::STARTTLS);
         } else {
             accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
         }
@@ -198,9 +197,9 @@ KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &ident
             accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
             query.addQueryItem(QStringLiteral("x-allow-unencrypted"), QStringLiteral("true"));
         } else if (resultSafety == QLatin1String("SSL")) {
-            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::AnySslVersion);
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::SSLorTLS);
         } else if (resultSafety == QLatin1String("STARTTLS")) {
-            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::TlsV1);
+            accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::STARTTLS);
         } else {
             accountInfo.sieveImapAccountSettings.setEncryptionMode(SieveImapAccountSettings::Unencrypted);
         }
@@ -210,11 +209,11 @@ KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &ident
         const QString resultCustomAuthentication = interface->sieveCustomAuthentification();
         if (resultCustomAuthentication == QLatin1String("ImapUserPassword")) {
             u.setUserName(interface->userName());
-            const QString pwd = provider->password(identifier);
-            u.setPassword(pwd);
+            const QString imapPwd = provider->password(identifier);
+            u.setPassword(imapPwd);
         } else if (resultCustomAuthentication == QLatin1String("CustomUserPassword")) {
-            const QString pwd = provider->sieveCustomPassword(identifier);
-            u.setPassword(pwd);
+            const QString customPwd = provider->sieveCustomPassword(identifier);
+            u.setPassword(customPwd);
             u.setUserName(interface->sieveCustomUsername());
         } else {
             qCWarning(LIBKSIEVE_LOG) << "resultCustomAuthentication undefined " << resultCustomAuthentication;
