@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@
 #include <QLineEdit>
 #include <QSpinBox>
 #include <QTest>
-#include <kpimtextedit/plaintexteditorwidget.h>
+#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <vacation/vacationmailactionwidget.h>
 #include <PimCommon/SpellCheckLineEdit>
 
@@ -197,27 +197,27 @@ void VacationEditWidgetTest::shouldGetValues()
 
 #if 0
     KMime::Types::AddrSpecList mailAliases() const;
-    void setMailAliases(const KMime::Types::AddrSpecList & aliases);
-    void setMailAliases(const QString & aliases);
+    void setMailAliases(const KMime::Types::AddrSpecList &aliases);
+    void setMailAliases(const QString &aliases);
 
     bool sendForSpam() const;
     void setSendForSpam(bool enable);
 
     QDate startDate() const;
-    void setStartDate(const QDate & startDate);
+    void setStartDate(const QDate &startDate);
 
     QTime startTime() const;
-    void setStartTime(const QTime & startTime);
+    void setStartTime(const QTime &startTime);
 
     QDate endDate() const;
-    void setEndDate(const QDate & endDate);
+    void setEndDate(const QDate &endDate);
 
     QTime endTime() const;
-    void setEndTime(const QTime & endTime);
+    void setEndTime(const QTime &endTime);
 
     VacationUtils::MailAction mailAction() const;
     QString mailActionRecipient() const;
-    void setMailAction(VacationUtils::MailAction action, const QString & recipient);
+    void setMailAction(VacationUtils::MailAction action, const QString &recipient);
 #endif
 }
 
