@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,10 +23,8 @@
 
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <kwindowsystem.h>
+#include <KMessageBox>
 #include <QTabWidget>
-#include <KIconLoader>
-#include <QUrl>
 
 #include <QTabBar>
 #include <QApplication>
@@ -46,7 +44,7 @@ public:
     {
     }
 
-    QList<VacationCreateScriptJob *> mListCreateJob;
+    QVector<VacationCreateScriptJob *> mListCreateJob;
     QTabWidget *mTabWidget = nullptr;
     QStackedWidget *mStackedWidget = nullptr;
     MultiImapVacationManager *mVacationManager = nullptr;
@@ -58,11 +56,7 @@ MultiImapVacationDialog::MultiImapVacationDialog(MultiImapVacationManager *manag
 {
     d->mVacationManager = manager;
 
-    setWindowTitle(i18n("Configure \"Out of Office\" Replies"));
-
-    KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)),
-                            qApp->windowIcon().pixmap(IconSize(KIconLoader::Small), IconSize(KIconLoader::Small)));
-
+    setWindowTitle(i18nc("@title:window", "Configure \"Out of Office\" Replies"));
     init();
     readConfig();
 }
@@ -84,7 +78,30 @@ void MultiImapVacationDialog::switchToServerNamePage(const QString &serverName)
     }
 }
 
-QList<VacationCreateScriptJob *> MultiImapVacationDialog::listCreateJob() const
+void MultiImapVacationDialog::reject()
+{
+    bool canCloseDialog = true;
+    for (int i = 0; i < d->mTabWidget->count(); ++i) {
+        VacationPageWidget *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
+        if (vacationPage) {
+            if (vacationPage->wasChanged()) {
+                if (KMessageBox::questionYesNo(
+                        this,
+                        i18nc("@info", "Do you really want to cancel?"),
+                        i18nc("@title:window", "Confirmation")) == KMessageBox::Yes) {
+                    QDialog::reject();     // Discard current changes
+                }
+                canCloseDialog = false;
+                break;
+            }
+        }
+    }
+    if (canCloseDialog) {
+        QDialog::reject();
+    }
+}
+
+QVector<VacationCreateScriptJob *> MultiImapVacationDialog::listCreateJob() const
 {
     return d->mListCreateJob;
 }
@@ -133,7 +150,7 @@ void MultiImapVacationDialog::init()
         connect(buttonBox, &QDialogButtonBox::accepted, this, &MultiImapVacationDialog::slotOkClicked);
         connect(buttonBox, &QDialogButtonBox::rejected, this, &MultiImapVacationDialog::slotCanceled);
         connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &MultiImapVacationDialog::slotDefaultClicked);
-    } else {
+    } else { //Empty
         d->mStackedWidget->setCurrentIndex(1);
         buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
         connect(buttonBox, &QDialogButtonBox::accepted, this, &MultiImapVacationDialog::slotOkClicked);
@@ -179,16 +196,28 @@ void MultiImapVacationDialog::writeConfig()
 
 void MultiImapVacationDialog::slotOkClicked()
 {
+    bool errorFound = false;
+    qDeleteAll(d->mListCreateJob);
+    d->mListCreateJob.clear();
     for (int i = 0; i < d->mTabWidget->count(); ++i) {
         VacationPageWidget *vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
-            VacationCreateScriptJob *job = vacationPage->writeScript();
-            if (job) {
+            VacationCreateScriptJob *job = vacationPage->writeScript(errorFound);
+
+            if (job && !errorFound) {
                 d->mListCreateJob.append(job);
             }
+            if (errorFound) {
+                //Clean up job
+                qDeleteAll(d->mListCreateJob);
+                d->mListCreateJob.clear();
+                break;
+            }
         }
     }
-    Q_EMIT okClicked();
+    if (!errorFound) {
+        Q_EMIT okClicked();
+    }
 }
 
 void MultiImapVacationDialog::slotDefaultClicked()
