@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,7 +24,7 @@
 #include <kmanagesieve/sievejob.h>
 
 #include <QDate>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include "libksieve_debug.h"
 
