@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -53,7 +53,7 @@ Q_SIGNALS:
 private Q_SLOTS:
     void slotPutResult(KManageSieve::SieveJob *job, bool success);
     void slotGetScript(KManageSieve::SieveJob *job, bool success, const QString &oldScript, bool active);
-    void slotGotActiveScripts(ParseUserScriptJob *job);
+    void slotGotActiveScripts(KSieveUi::ParseUserScriptJob *job);
     void slotGenerateDone(const QString &error = QString());
 
 private:
