@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,7 +29,8 @@
 #include <QLineEdit>
 #include <QRegularExpressionValidator>
 
-#include <kpimtextedit/plaintexteditorwidget.h>
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <KPIMTextEdit/PlainTextEditor>
 #include "libksieve_debug.h"
 
 #include <kmime/kmime_header_parsing.h>
@@ -37,6 +38,7 @@
 #include <QCheckBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <PimCommon/SpellCheckLineEdit>
 
 using KMime::Types::AddrSpecList;
 using KMime::Types::AddressList;
@@ -50,7 +52,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     int row = -1;
 
     QGridLayout *glay = new QGridLayout(this);
-    glay->setMargin(0);
+    glay->setContentsMargins(0, 0, 0, 0);
     glay->setColumnStretch(1, 1);
 
     // explanation label:
@@ -65,6 +67,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mActiveCheck = new QCheckBox(i18n("&Activate vacation notifications"), this);
     mActiveCheck->setObjectName(QStringLiteral("mActiveCheck"));
     glay->addWidget(mActiveCheck, row, 0, 1, 2);
+    connect(mActiveCheck, &QCheckBox::clicked, this, &VacationEditWidget::setWasChanged);
 
     // Message text edit:
     ++row;
@@ -72,12 +75,14 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mTextEdit = new KPIMTextEdit::PlainTextEditorWidget(this);
     mTextEdit->setObjectName(QStringLiteral("mTextEdit"));
     glay->addWidget(mTextEdit, row, 0, 1, 2);
+    connect(mTextEdit->editor(), &KPIMTextEdit::PlainTextEditor::textChanged, this, &VacationEditWidget::setWasChanged);
 
     // Subject
     ++row;
-    mSubject = new QLineEdit(this);
+    mSubject = new PimCommon::SpellCheckLineEdit(this, QString());
     mSubject->setObjectName(QStringLiteral("mSubject"));
-    mSubject->setClearButtonEnabled(true);
+    connect(mSubject, &PimCommon::SpellCheckLineEdit::textChanged, this, &VacationEditWidget::setWasChanged);
+    //mSubject->setClearButtonEnabled(true);
     QLabel *subjectOfVacationLabel = new QLabel(i18n("&Subject of the vacation mail:"), this);
     subjectOfVacationLabel->setObjectName(QStringLiteral("subjectOfVacationLabel"));
     subjectOfVacationLabel->setBuddy(mSubject);
@@ -90,11 +95,15 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mStartDate = new KDateComboBox(this);
     mStartDate->setObjectName(QStringLiteral("mStartDate"));
     mStartDate->setOptions(KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker | KDateComboBox::DateKeywords);
+    connect(mStartDate, &KDateComboBox::dateChanged, this, &VacationEditWidget::setWasChanged);
+    connect(mStartDate, &KDateComboBox::dateEdited, this, &VacationEditWidget::setWasChanged);
 
     mStartTime = new KTimeComboBox(this);
     mStartTime->setObjectName(QStringLiteral("mStartTime"));
-    mStartTime->setOptions(KTimeComboBox::EditTime | KTimeComboBox::SelectTime | KTimeComboBox::EditTime | KTimeComboBox::WarnOnInvalid);
+    mStartTime->setOptions(KTimeComboBox::EditTime | KTimeComboBox::SelectTime | KTimeComboBox::WarnOnInvalid);
     mStartTime->setEnabled(false); // Disable by default - we need an extension to support this
+    connect(mStartTime, &KTimeComboBox::timeChanged, this, &VacationEditWidget::setWasChanged);
+    connect(mStartTime, &KTimeComboBox::timeEdited, this, &VacationEditWidget::setWasChanged);
 
     mStartTimeActive = new QCheckBox(this);
     mStartTimeActive->setObjectName(QStringLiteral("mStartTimeActive"));
@@ -117,15 +126,20 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mEndDate = new KDateComboBox(this);
     mEndDate->setObjectName(QStringLiteral("mEndDate"));
     mEndDate->setOptions(KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker | KDateComboBox::DateKeywords);
+    connect(mEndDate, &KDateComboBox::dateChanged, this, &VacationEditWidget::setWasChanged);
+    connect(mEndDate, &KDateComboBox::dateEdited, this, &VacationEditWidget::setWasChanged);
 
     mEndTime = new KTimeComboBox(this);
     mEndTime->setObjectName(QStringLiteral("mEndTime"));
-    mEndTime->setOptions(KTimeComboBox::EditTime | KTimeComboBox::SelectTime | KTimeComboBox::EditTime | KTimeComboBox::WarnOnInvalid);
+    mEndTime->setOptions(KTimeComboBox::EditTime | KTimeComboBox::SelectTime | KTimeComboBox::WarnOnInvalid);
     mEndTime->setEnabled(false); // Disable by default - we need an extension to support this
+    connect(mEndTime, &KTimeComboBox::timeChanged, this, &VacationEditWidget::setWasChanged);
+    connect(mEndTime, &KTimeComboBox::timeEdited, this, &VacationEditWidget::setWasChanged);
 
     mEndTimeActive = new QCheckBox(this);
     mEndTimeActive->setObjectName(QStringLiteral("mEndTimeActive"));
     connect(mEndTimeActive, &QCheckBox::toggled, mEndTime, &KTimeComboBox::setEnabled);
+    connect(mEndTimeActive, &QCheckBox::toggled, this, &VacationEditWidget::setWasChanged);
 
     mEndDateLabel = new QLabel(i18n("End date:"), this);
     mEndDateLabel->setObjectName(QStringLiteral("mEndDateLabel"));
@@ -137,7 +151,6 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     timeLayout->addWidget(mEndTime);
     glay->addLayout(timeLayout, row, 1);
 
-
     // Hide the date edits by default - they must be enabled by caller when the
     // server supports this feature
     enableDates(false);
@@ -164,6 +177,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mMailAliasesEdit = new KSieveUi::VacationMailLineEdit(this);
     mMailAliasesEdit->setObjectName(QStringLiteral("mMailAliasesEdit"));
     mMailAliasesEdit->setClearButtonEnabled(true);
+    connect(mMailAliasesEdit, &KSieveUi::VacationMailLineEdit::textChanged, this, &VacationEditWidget::setWasChanged);
     QLabel *sendResponseLabel = new QLabel(i18n("&Send responses for these addresses:"), this);
     sendResponseLabel->setObjectName(QStringLiteral("sendResponseLabel"));
     sendResponseLabel->setBuddy(mMailAliasesEdit);
@@ -181,6 +195,8 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     //Add imap select folder plugin here.
     mMailActionRecipient = new VacationMailActionWidget(this);
     mMailActionRecipient->setObjectName(QStringLiteral("mMailActionRecipient"));
+    connect(mMailActionRecipient, &VacationMailActionWidget::wasChanged, this, &VacationEditWidget::setWasChanged);
+    //Add setChanged here too
 
     QHBoxLayout *hLayout = new QHBoxLayout;
 
@@ -200,12 +216,15 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     mSpamCheck->setObjectName(QStringLiteral("mSpamCheck"));
     mSpamCheck->setChecked(true);
     glay->addWidget(mSpamCheck, row, 0, 1, 2);
+    connect(mSpamCheck, &QCheckBox::clicked, this, &VacationEditWidget::setWasChanged);
 
     //  domain checkbox and linedit:
     ++row;
     mDomainCheck = new QCheckBox(i18n("Only react to mail coming from domain"), this);
     mDomainCheck->setObjectName(QStringLiteral("mDomainCheck"));
     mDomainCheck->setChecked(false);
+    connect(mDomainCheck, &QCheckBox::clicked, this, &VacationEditWidget::setWasChanged);
+
     mDomainEdit = new QLineEdit(this);
     mDomainEdit->setObjectName(QStringLiteral("mDomainEdit"));
     mDomainEdit->setClearButtonEnabled(true);
@@ -214,6 +233,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
     glay->addWidget(mDomainCheck, row, 0);
     glay->addWidget(mDomainEdit, row, 1);
     connect(mDomainCheck, &QCheckBox::toggled, mDomainEdit, &QLineEdit::setEnabled);
+    connect(mDomainEdit, &QLineEdit::textChanged, this, &VacationEditWidget::setWasChanged);
 }
 
 VacationEditWidget::~VacationEditWidget()
@@ -259,7 +279,6 @@ AddrSpecList VacationEditWidget::mailAliases(bool &ok) const
     const char *s = text.cbegin();
     AddrSpecList asl;
     if (parseAddressList(s, text.cend(), al)) {
-
         AddressList::const_iterator end(al.constEnd());
         for (AddressList::const_iterator it = al.constBegin(); it != end; ++it) {
             const MailboxList &mbl = (*it).mailboxList;
@@ -285,7 +304,7 @@ void VacationEditWidget::setMailAliases(const AddrSpecList &aliases)
     for (AddrSpecList::const_iterator it = aliases.constBegin(); it != end; ++it) {
         sl.push_back((*it).asString());
     }
-    mMailAliasesEdit->setText(sl.join(QStringLiteral(", ")));
+    mMailAliasesEdit->setText(sl.join(QLatin1String(", ")));
 }
 
 void VacationEditWidget::setMailAliases(const QString &aliases)
@@ -296,6 +315,7 @@ void VacationEditWidget::setMailAliases(const QString &aliases)
 void VacationEditWidget::slotIntervalSpinChanged(int value)
 {
     mIntervalSpin->setSuffix(i18np(" day", " days", value));
+    setWasChanged();
 }
 
 QString VacationEditWidget::domainName() const
@@ -340,7 +360,7 @@ QDate VacationEditWidget::endDate() const
     }
 }
 
-void VacationEditWidget::setEndDate(const QDate &endDate)
+void VacationEditWidget::setEndDate(QDate endDate)
 {
     mEndDate->setDate(endDate);
 }
@@ -354,7 +374,7 @@ QTime VacationEditWidget::endTime() const
     }
 }
 
-void VacationEditWidget::setEndTime(const QTime &endTime)
+void VacationEditWidget::setEndTime(QTime endTime)
 {
     mEndTimeActive->setChecked(endTime.isValid());
     mEndTime->setEnabled(endTime.isValid());
@@ -370,7 +390,7 @@ QDate VacationEditWidget::startDate() const
     }
 }
 
-void VacationEditWidget::setStartDate(const QDate &startDate)
+void VacationEditWidget::setStartDate(QDate startDate)
 {
     mStartDate->setDate(startDate);
 }
@@ -384,7 +404,7 @@ QTime VacationEditWidget::startTime() const
     }
 }
 
-void VacationEditWidget::setStartTime(const QTime &startTime)
+void VacationEditWidget::setStartTime(QTime startTime)
 {
     mStartTimeActive->setChecked(startTime.isValid());
     mStartTime->setEnabled(startTime.isValid());
@@ -399,7 +419,7 @@ void VacationEditWidget::setSubject(const QString &subject)
 QString VacationEditWidget::subject() const
 {
     if (mSubject->isEnabled()) {
-        return mSubject->text();
+        return mSubject->toPlainText();
     } else {
         return QString();
     }
@@ -420,6 +440,22 @@ void VacationEditWidget::enableDates(bool enable)
 void VacationEditWidget::mailActionChanged(int action)
 {
     mMailActionRecipient->mailActionChanged(static_cast<KSieveUi::VacationUtils::MailAction>(action));
+    setWasChanged();
+}
+
+void VacationEditWidget::setWasChanged()
+{
+    mChanged = true;
+}
+
+bool VacationEditWidget::changed() const
+{
+    return mChanged;
+}
+
+void VacationEditWidget::setChanged(bool changed)
+{
+    mChanged = changed;
 }
 
 void VacationEditWidget::setMailAction(VacationUtils::MailAction action, const QString &recipient)
