@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -111,8 +111,19 @@ void VacationPageWidget::slotGetResult(const QString &serverName, const QStringL
     if (mServerName != serverName) {
         return;
     }
-    qCDebug(LIBKSIEVE_LOG) << serverName << sieveCapabilities << endl
-                           << scriptName << "(" << active << ")" << endl;
+    qCDebug(LIBKSIEVE_LOG) << serverName << sieveCapabilities
+                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+        << endl
+                          #else
+        << Qt::endl
+                          #endif
+        << scriptName << "(" << active << ")"
+                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+        << endl
+                          #else
+        << Qt::endl
+                          #endif
+    ;
 
     if (mUrl.scheme() == QLatin1String("sieve")
         && !sieveCapabilities.contains(QLatin1String("vacation"))) {
