@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -68,7 +68,7 @@ ManageSieveWidget::ManageSieveWidget(QWidget *parent)
     , d(new KSieveUi::ManageSieveWidgetPrivate)
 {
     QHBoxLayout *lay = new QHBoxLayout(this);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     d->mTreeView = new ManageSieveTreeView(this);
 #ifndef QT_NO_CONTEXTMENU
@@ -86,6 +86,7 @@ ManageSieveWidget::ManageSieveWidget(QWidget *parent)
 
 ManageSieveWidget::~ManageSieveWidget()
 {
+    disconnect(d->mTreeView, &ManageSieveTreeView::itemSelectionChanged, this, &ManageSieveWidget::slotUpdateButtons);
     clear();
     delete d;
 }
@@ -191,7 +192,7 @@ bool ManageSieveWidget::canAddNewScript(QTreeWidgetItem *item, bool jobsListIsEm
             return false;
         }
 
-        if (!mUrls.count(item)) {
+        if (!mUrls.contains(item)) {
             return false;
         }
         return true;
@@ -225,7 +226,7 @@ void ManageSieveWidget::slotNewScript()
         return;
     }
 
-    if (!mUrls.count(currentItem)) {
+    if (!mUrls.contains(currentItem)) {
         return;
     }
 
@@ -295,7 +296,7 @@ void ManageSieveWidget::slotEditScript()
         return;
     }
     QTreeWidgetItem *parent = currentItem->parent();
-    if (!mUrls.count(parent)) {
+    if (!mUrls.contains(parent)) {
         return;
     }
     QUrl url = mUrls[parent];
@@ -335,10 +336,10 @@ void ManageSieveWidget::changeActiveScript(QTreeWidgetItem *item, bool activate)
     if (!item) {
         return;
     }
-    if (!mUrls.count(item)) {
+    if (!mUrls.contains(item)) {
         return;
     }
-    if (!d->mSelectedItems.count(item)) {
+    if (!d->mSelectedItems.contains(item)) {
         return;
     }
     QUrl u = mUrls[item];
@@ -418,7 +419,7 @@ void ManageSieveWidget::slotRenameScript()
         return;
     }
 
-    if (!mUrls.count(parent)) {
+    if (!mUrls.contains(parent)) {
         return;
     }
 
@@ -481,7 +482,7 @@ void ManageSieveWidget::slotDeleteScript()
         return;
     }
 
-    if (!mUrls.count(parent)) {
+    if (!mUrls.contains(parent)) {
         return;
     }
 
@@ -581,7 +582,8 @@ void ManageSieveWidget::slotGotList(KManageSieve::SieveJob *job, bool success, c
         QUrl u = mUrls[parent];
         u = u.adjusted(QUrl::RemoveFilename);
         u.setPath(u.path() + QLatin1Char('/') + QStringLiteral("USER"));
-        ParseUserScriptJob *parseJob = new ParseUserScriptJob(u);
+        ParseUserScriptJob *parseJob = new ParseUserScriptJob(u, this);
+        parseJob->setAutoDelete(true);
         parseJob->setProperty("parentItem", QVariant::fromValue<QTreeWidgetItem *>(parent));
         connect(parseJob, &ParseUserScriptJob::finished, this, &ManageSieveWidget::setActiveScripts);
         parseJob->start();
@@ -649,7 +651,7 @@ void ManageSieveWidget::enableDisableActions(bool &newScriptAction, bool &editSc
     bool enabled = true;
     if (!item) {
         enabled = false;
-    } else if (!item->parent() && !mUrls.count(item)) {
+    } else if (!item->parent() && !mUrls.contains(item)) {
         enabled = false;
     }
 
@@ -662,7 +664,7 @@ void ManageSieveWidget::enableDisableActions(bool &newScriptAction, bool &editSc
         if (serverHasError(item) || !mJobs.keys(item).isEmpty()) {
             newScriptAction = false;
         } else {
-            newScriptAction = mUrls.count(item);
+            newScriptAction = mUrls.contains(item);
         }
         enabled = isFileNameItem(item);
         editScriptAction = enabled;
